"""Package for code relating to selection in GUI.
"""
from .selection_object import (find_edge_in_selection_object,
                               find_face_in_selection_object,
                               find_selection_object_by_type,
                               find_vertex_in_selection_object)
